SystemOrganization addCategory: #ConfigurationOfSQLite3!

Object subclass: #ConfigurationOfSQLite3
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSQLite3'!

!ConfigurationOfSQLite3 class methodsFor: 'private' stamp: 'tbn 1/13/2010 13:11'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSQLite3 class methodsFor: 'private' stamp: 'tbn 1/13/2010 13:11'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfSQLite3 class methodsFor: 'metacello tool support' stamp: 'tbn 1/13/2010 13:10'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSQLite3 class methodsFor: 'metacello tool support' stamp: 'tbn 1/13/2010 13:10'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSQLite3 class methodsFor: 'loading' stamp: 'tbn 2/19/2010 23:18'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfSQLite3 class methodsFor: 'metacello tool support' stamp: 'tbn 1/13/2010 13:11'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSQLite3 class methodsFor: 'accessing' stamp: 'tbn 1/13/2010 13:10'!
project

	^self new project! !

!ConfigurationOfSQLite3 methodsFor: 'baselines' stamp: 'tbn 3/12/2013 20:45'!
baseline10: spec
    <version: '1.0-baseline'>
    
    spec for: #common do: [
        spec 
			blessing: #baseline;
			description: '1.0 baseline for SQLite 3';
			repository: 'http://smalltalkhub.com/mc/TorstenBergmann/SQLite/main'.     
			 
        spec package: 'SQLite3-Core' with: [ spec requires: #('FFI' ) ].
		 spec package: 'SQLite3-Tests' with: [ spec requires: #('SQLite3-Core' ) ].		
				
		 spec
			group: 'default' with: #('SQLite3-Core' );
			group: 'Tests' with: #('SQLite3-Tests' ).
							
	  spec
			project: 'FFI' with: [
				spec
					className: 'ConfigurationOfFFI';
					file: 'ConfigurationOfFFI';
					version: '1.0-baseline';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
    ]
      
        
! !

!ConfigurationOfSQLite3 methodsFor: 'accessing' stamp: 'tbn 1/13/2010 13:05'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfSQLite3 methodsFor: 'symbolic versions' stamp: 'tbn 3/12/2013 19:26'!
stable: spec
	<symbolicVersion: #'stable'>
	
	spec  for: #common version: '1.3'! !

!ConfigurationOfSQLite3 methodsFor: 'versions' stamp: 'tbn 1/25/2010 21:17'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'first release'. 
		spec author: 'Torsten Bergmann'.
		spec timestamp: '1/25/2010 8:49'.
		spec 
			project: 'FFI' with: '1.0'.	 
		spec package: 'SQLite3-Core' with: 'SQLite3-Core-tbn.1'.
		spec package: 'SQLite3-Tests' with: 'SQLite3-Tests-tbn.1'.		
	]! !

!ConfigurationOfSQLite3 methodsFor: 'versions' stamp: 'tbn 2/18/2010 00:14'!
version11: spec
	<version: '1.1' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'release with newer FFI'. 
		spec author: 'Torsten Bergmann'.
		spec timestamp: '2/18/2010 0:10'.
		spec 
			project: 'FFI' with: '1.2'.	 
		spec package: 'SQLite3-Core' with: 'SQLite3-Core-tbn.1'.
		spec package: 'SQLite3-Tests' with: 'SQLite3-Tests-tbn.1'.		
	]! !

!ConfigurationOfSQLite3 methodsFor: 'versions' stamp: 'tbn 1/4/2012 09:12'!
version12: spec
	<version: '1.2' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'release with working on Mac too'. 
		spec author: 'Torsten Bergmann'.
		spec timestamp: '5/19/2010 0:10'.
		spec 
			project: 'FFI' with: '1.2'.	 
		spec package: 'SQLite3-Core' with: 'SQLite3-Core-tbn.5'.
		spec package: 'SQLite3-Tests' with: 'SQLite3-Tests-spd.2'.		
	]! !

!ConfigurationOfSQLite3 methodsFor: 'versions' stamp: 'tbn 3/12/2013 20:03'!
version13: spec
	<version: '1.3' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'adopt to new file system API'. 
		spec author: 'Torsten Bergmann'.
		spec timestamp: '3/13/2013 0:10'.
		spec 
			project: 'FFI' with: '1.7'.	 
		spec package: 'SQLite3-Core' with: 'SQLite3-Core-ar.8'.
		spec package: 'SQLite3-Tests' with: 'SQLite3-Tests-tbn.5'.		
	]! !
